@@ -5,14 +5,13 @@ import zipfile
 import contextlib
 
 from ncbi.datasets.reports.report_reader import DatasetsReportReader
-
 import ncbi.datasets.v1alpha1.reports.assembly_pb2 as assembly_report_pb2
 import ncbi.datasets.v1alpha1.reports.gene_pb2 as gene_report_pb2
 
 logger = logging.getLogger()
 
 
-def GetDatasetFromFile(zip_file_or_directory, dataset_type):
+def GetDatasetFromFile(zip_file_or_directory, dataset_type):  # pylint:disable=invalid-name
     if dataset_type == 'ASSEMBLY':
         return AssemblyDataset(zip_file_or_directory)
     elif dataset_type == 'GENE':
@@ -25,7 +24,7 @@ def GetDatasetFromFile(zip_file_or_directory, dataset_type):
 def _get_files_of_type(elt, file_type, results):
     if isinstance(elt, dict):
         for k, v in elt.items():
-            if k == "files" and isinstance(v, list):
+            if k == 'files' and isinstance(v, list):
                 results.extend([f['filePath'] for f in v if f['fileType'] == file_type])
             else:
                 _get_files_of_type(v, file_type, results)
@@ -37,7 +36,7 @@ def _get_files_of_type(elt, file_type, results):
 def _get_file_types(elt, results):
     if isinstance(elt, dict):
         for k, v in elt.items():
-            if k == "files" and isinstance(v, list):
+            if k == 'files' and isinstance(v, list):
                 results.update([f['fileType'] for f in v])
             else:
                 _get_file_types(v, results)
@@ -47,6 +46,11 @@ def _get_file_types(elt, results):
 
 
 class Dataset():
+    """Base class to extract files from datasets package
+
+    Various low-level functions to extract files from a datasets package
+    """
+
     def __init__(self, zipfile_or_directory):
         self.report_reader = DatasetsReportReader()
         # Zip file object - is 'None' if dataset is not stored in a zip file
@@ -57,15 +61,15 @@ class Dataset():
         self._dataset_catalog = {}
 
         if os.path.isdir(zipfile_or_directory):
-            self.dataset_dir = os.path.join(zipfile_or_directory, "data")
+            self.dataset_dir = os.path.join(zipfile_or_directory, 'data')
         elif os.path.isfile(zipfile_or_directory):
             try:
                 self.dataset_zip = zipfile.ZipFile(zipfile_or_directory)
-                self.dataset_dir = "ncbi_dataset/data"
+                self.dataset_dir = 'ncbi_dataset/data'
             except zipfile.BadZipFile as e:
-                logger.error(f"Bad zipfile: {e}")
+                logger.error('Bad zipfile: %s', e)
         else:
-            logger.error(f"Invalid file or directory {zipfile_or_directory}")
+            logger.error('Invalid file or directory %s', zipfile_or_directory)
 
     # True if Dataset is reading directly from a zip file
     def is_zipped(self):
@@ -85,7 +89,7 @@ class Dataset():
             try:
                 self._dataset_catalog = json.loads(catalog_file)
             except json.JSONDecodeError as e:
-                logger.error(f"Error decoding dataset_catalog file to json: {e}")
+                logger.error('Error decoding dataset_catalog file to json: %s', e)
         return self._dataset_catalog
 
     # return names of all files of type 'file_type', eg. 'PROTEIN_FASTA'
@@ -120,7 +124,7 @@ class Dataset():
     def get_file_content(self, file_name):
         with self.get_file_handle(file_name) as fh:
             if not fh:
-                return ""
+                return ''
             return fh.read()
 
     # Get handle of file using name within dataset directory 'ncbi_dataset/data'.
@@ -134,65 +138,87 @@ class Dataset():
                 with self.dataset_zip.open(zinfo)as fh:
                     yield fh
             except KeyError as e:
-                logger.error(f"File {file_name} not found in zipfile: {e}")
+                logger.error('File %s not found in zipfile: %s', file_name, e)
         elif self.dataset_dir:
             file_path = os.path.join(self.dataset_dir, file_name)
             if os.path.exists(file_path):
                 with open(file_path, 'r') as fh:
                     yield fh
             else:
-                logger.error(f"File not found in datasets directory: {file_path}")
+                logger.error('File not found in datasets directory: %s', file_path)
         else:
-            logger.error(f"Dataset not available - unable to load: {file_name}")
-
-        return None
+            logger.error('Dataset not available - unable to load: %s', file_name)
 
 
-# Dataset subclasses provide report files based on schema
 class AssemblyDataset(Dataset):
-    def __init__(self, zip_file_or_directory):
-        super().__init__(zip_file_or_directory)
+    """Retrieve Assembly reports
+
+    Methods to read Assembly reports
+    """
 
     # returns protobuf for single report
     def get_report(self, report_file):
+        """Retrieve assembly reports
+
+        Returns:
+          A single AssemblyDataReport protobuf object
+        """
+
         with self.get_file_handle(report_file) as fh:
-            return self.report_reader.assembly_report(fh)
+            return self.report_reader.assembly_report_from_file(fh)
         return assembly_report_pb2.AssemblyDataReport()
 
-    # assembly datasets have multiple reports, and this returns them one at at time
     def get_reports(self):
+        """Retrieve assembly reports
+
+        Returns:
+          Yields a set of AssemblyDataReport protobuf object
+        """
+
         report_files = self.get_file_names_by_type('DATA_REPORT')
         for file in report_files:
             with self.get_file_handle(file) as fh:
-                yield self.report_reader.assembly_report(fh)
+                yield self.report_reader.assembly_report_from_file(fh)
         return assembly_report_pb2.AssemblyDataReport()
 
 
 class GeneDataset(Dataset):
-    def __init__(self, zip_file_or_directory):
-        super().__init__(zip_file_or_directory)
+    """Retrieve Gene reports
+
+    Methods to read Gene reports
+    """
 
-    # returns protobuf for single report.  Maybe defaults to first/only report
     def get_report(self):
+        """Retrieve a gene report object
+
+        Returns:
+          A single GeneDescriptors protobuf object
+        """
+
         report_files = self.get_file_names_by_type('DATA_REPORT')
         # gene datasets also have '.csv' files of type DATA_REPORT, but these
         # can't be converted to protobuf
-        file = next(file for file in report_files if file.endswith("yaml"))
+        file = next(file for file in report_files if file.endswith('yaml'))
         if file:
             with self.get_file_handle(file) as fh:
-                return self.report_reader.gene_report(fh)
+                return self.report_reader.gene_report_from_file(fh)
         return gene_report_pb2.GeneDescriptors()
 
 
 class VirusDataset(Dataset):
-    def __init__(self, zip_file_or_directory):
-        super().__init__(zip_file_or_directory)
+    """Retrieve Virus reports
+
+    Methods to read Virus reports
+    """
 
-    # iterates over virus assemblies in report and returns them one at a time
     def get_report_assemblies(self):
+        """Retrieve virus assembly objects
+
+        Returns:
+          Yields a set of virus assembly report protobuf objects
+        """
         report_files = self.get_file_names_by_type('DATA_REPORT')
         if report_files:
             with self.get_file_handle(report_files[0]) as fh:
-                virus_assm_gen = self.report_reader.read_virus_report(fh)
-                for virus_assm_pb in virus_assm_gen:
+                for virus_assm_pb in self.report_reader.read_virus_report(fh):
                     yield virus_assm_pb
