@@ -12,18 +12,17 @@ logger = logging.getLogger()
 
 
 class BdBag():
-    ''' BdBag is a wrapper to present a simplified interface to the dbbag api:
+    """ BdBag is a wrapper to present a simplified interface to the dbbag api:
     https://github.com/fair-research/bdbag/blob/master/doc/api.md#archive_bag
-    '''
+    """
 
     # tuple with fields required for remote-file manifiest
-    RemoteFile = collections.namedtuple(
-        'RemoteFile', 'url filename length md5')
+    RemoteFile = collections.namedtuple('RemoteFile', 'url filename length md5')  # pylint:disable=invalid-name
 
     def __init__(self, package_name):
-        ''' Create a temp directory for building the bag and create a directory
+        """ Create a temp directory for building the bag and create a directory
         inside of that called 'package_name'
-        '''
+        """
         self.tmp_package_dir = tempfile.TemporaryDirectory()
         self.package_dir = os.path.join(
             self.tmp_package_dir.name, package_name)
@@ -48,25 +47,25 @@ class BdBag():
         with open(filename, 'w', newline='\r\n') as fh:
             yield fh
 
-    def create_bag(self, remote_files=None, hydrated_bag=True, readme_file=""):
+    def create_bag(self, remote_files=None, hydrated_bag=True, readme_file=''):
         self.make_bag(remote_files)
         if remote_files and hydrated_bag:
             self.hydrated_bag()
         return self.archive_bag(readme_file)
 
     def make_bag(self, remote_files=None):
-        ''' Perform all steps to create and archive the bag including
+        """ Perform all steps to create and archive the bag including
         writing the remote files manifest (if provided) as json.
 
         Args:
             remote_files (list of FtpFile namedtuples) All the files that will be
                 written to fetch.txt as remote files
-        '''
+        """
         remote_manifest_f = None
         algs = ['md5']
         if remote_files:
             remote_manifest_f = tempfile.NamedTemporaryFile(
-                mode="w", delete=False)
+                mode='w', delete=False)
             print(
                 json.dumps([ftp_file._asdict() for ftp_file in remote_files]),
                 file=remote_manifest_f
@@ -89,20 +88,20 @@ class BdBag():
     def hydrated_bag(self):
         bdbag_api.hydrated_fetch(self.package_dir)
 
-    def archive_bag(self, readme_file=""):
-        ''' Validate and archive (via zip) the contents of the bdbag adding, optionally,
+    def archive_bag(self, readme_file=''):
+        """ Validate and archive (via zip) the contents of the bdbag adding, optionally,
         a readme file in the top-level directory. This functionality is essentially
         the same as bdbag_api.archive_bag function except for the addition of the README
         file (and it also supports other compression schemes).
-        '''
+        """
 
         try:
             bdbag_api.validate_bag_structure(self.package_dir, skip_remote=True)
         except Exception as e:
-            logger.error("Error while archiving bag: %s", e)
+            logger.error('Error while archiving bag: %s', e)
             raise e
 
-        zfp = '.'.join([self.package_dir, "zip"])
+        zfp = '.'.join([self.package_dir, 'zip'])
         with zipfile.ZipFile(zfp, 'w', compression=zipfile.ZIP_DEFLATED, allowZip64=True) as zf:
             if readme_file:
                 # Need to convert to crlf line endings, so read and write instead of copy
@@ -114,14 +113,14 @@ class BdBag():
                     rfile.write(content)
                 zf.write(readme_target_file, readme_base_fname)
 
-            for dirpath, dirnames, filenames in os.walk(self.package_dir):
+            for dirpath, _, filenames in os.walk(self.package_dir):
                 for name in filenames:
                     filepath = os.path.normpath(os.path.join(dirpath, name))
                     relpath = os.path.relpath(filepath, self.tmp_package_dir.name)
                     if os.path.isfile(filepath):
                         zf.write(filepath, relpath)
 
-        logger.info('Created bag archive: %s' % zf.filename)
+        logger.info('Created bag archive: %s', zf.filename)
         self.archived_file = zf.filename
 
         return self.archived_file
